# Repr Formatting API

Scikit-learn style repr and HTML formatting.

## ReprMixin

::: pyreprint.formatting.repr.ReprMixin

## format_repr

::: pyreprint.formatting.repr.format_repr

## ReprConfig

::: pyreprint.formatting.repr.ReprConfig

## HTML Formatting

### html_repr

::: pyreprint.formatting.html.html_repr

### HTMLFormatter

::: pyreprint.formatting.html.HTMLFormatter

### display_html

::: pyreprint.formatting.html.display_html

